<?php
function hotsugar_option($index, $default = ''){
    global $hotsugar_redux;
    if ( isset( $hotsugar_redux[ $index ]) ) {
        return $hotsugar_redux[$index];
    } else {
        return $default;
    }
}
function hotsugar_metabox($index, $default = ''){
    global $post;
    $metabox = !empty($post->ID) ? get_post_meta( $post->ID, HOTSUGAR_META, true ) : '';
    if ( isset( $metabox[ $index ]) ) {
        return $metabox[$index];
    } else {
        return $default;
    }
}
function hotsugar_metaboxes(){
    global $post;
    if ($post) {
        return get_post_meta( $post->ID, HOTSUGAR_META, true );
    }
    return false;
}
function hotsugar_favicon() {
    if(!function_exists('wp_site_icon') || !has_site_icon()){
        $fav = hotsugar_option('favicon');
        if (!empty($fav['url'])) {
            $favicon = $fav['url'];
        } else {
            $favicon = HOTSUGAR_DIR . 'assets/img/favicon.png';
        }
        echo '<link rel="shortcut icon" href="' . esc_url($favicon) . '" />' . "\n";
    }
}

// Print menu
//=======================================================
function hotsugar_menu() {
    wp_nav_menu(array(
        'container' => false,
        'menu_id' => '',
        'menu_class' => 'sf-menu',
        'fallback_cb' => 'hotsugar_nomenu',
        'theme_location' => 'main'
    ));
}
function hotsugar_top_menu(){
    wp_nav_menu(array(
        'container' => false,
        'menu_class' => 'sf-menu',
        'fallback_cb' => 'hotsugar_nomenu',
        'theme_location' => 'top'
    ));
}

function hotsugar_nomenu() {
    echo "<ul class='sf-menu'>";
        $howmany = 5;
        $pages=wp_list_pages(array('title_li'=>'','echo'=>0));
        preg_match_all('/(<li.*?>)(.*?)<\/li>/i', $pages, $matches);
        if(!empty($matches[0])){echo implode("\n", array_slice($matches[0],0,5));}
    echo "</ul>";
}
function hotsugar_mobilemenu($loc = 'main') {
    wp_nav_menu(array(
        'container' => false,
        'menu_id' => '',
        'menu_class' => 'sf-mobile-menu clearfix',
        'fallback_cb' => 'hotsugar_nomobile',
        'theme_location' => $loc)
    );
}

function hotsugar_nomobile() {
    echo "<ul class='clearfix'>";
    wp_list_pages(array('title_li' => ''));
    echo "</ul>";
}


// Print logo
//=======================================================
function hotsugar_logo() {
    $logo = hotsugar_option("logo");
    $output = '<div class="tw-logo">';
        if ( !empty($logo['url']) ) {
            $output .= '<a class="logo" href="' . esc_url(home_url('/')) . '">';
                $output .= '<img class="logo-img" src="' . esc_url($logo['url']) . '" alt="' . esc_attr(get_bloginfo('name')) . '"/>';
            $output .= '</a>';
        } else {
            $output .= '<h1 class="site-name"><a class="logo" href="' . esc_url(home_url('/')) . '">';
                $output .= get_bloginfo('name');
            $output .= '<span class="logo-point">.</span></a></h1>';
        }
    $output .= '</div>';
    return $output;
}

function hotsugar_single_scrollbar(){
    if(is_single()){
        if(hotsugar_option('single_scroll')){
            $social_color = hotsugar_option('single_scrollbar_social');
            echo '<div class="blog-single-nav">';
                echo '<div class="container">';
                    echo '<div>';
                        echo hotsugar_logo();
                        echo '<h2>'; the_title(); echo '</h2>';
                    echo '</div>';
                    $post_image = hotsugar_image('full', true);
                    echo '<div class="entry-share '. esc_attr($social_color) .'" data-ajaxurl="'.esc_url(home_url('/')).'" data-id="'.esc_attr(get_the_id()).'">';
                        echo '<div class="total-shares"><em>'.hotsugar_share_count().'</em><div class="caption">'. esc_html__('Shares', 'hotsugar') .'</div></div>';
                        echo '<a class="facebook" href="' . esc_url(get_permalink()) . '" title="Share this"><i class="ion-social-facebook"></i></a>';
                        echo '<a class="twitter" href="' . esc_url(get_permalink()) . '" title="Tweet" data-title="' . esc_attr(get_the_title()) . '"><i class="ion-social-twitter"></i></a>';
                        echo '<a class="pinterest" href="' . esc_url(get_permalink()) . '" title="Pin It" data-image="' . esc_attr($post_image['url']) . '"><i class="ion-social-pinterest"></i></a>';
                    echo '</div>';
                echo '</div>';
                echo '<div id="scroll-bar"></div>';
            echo '</div>';
        }
    }
}

// ThemeWaves Pagination
//=======================================================
function hotsugar_pagination($type = 'simple') { 
    global $wp_query;
    $pages = intval($wp_query->max_num_pages);
    $paged = (get_query_var('paged')) ? intval(get_query_var('paged')) : 1;
    if (empty($pages)) {
        $pages = 1;
    }
    if($type == 'simple' && 1 != $pages){
        echo '<div class="tw-pagination tw-hover tw-meta clearfix">';
            echo '<div class="older">';
                next_posts_link('<span>'.hotsugar_option('text_older', esc_html__( 'Older Posts', 'hotsugar')).'</span><i class="ion-ios-arrow-thin-right"></i>' );
            echo '</div><div class="newer">';
                previous_posts_link('<span>'.hotsugar_option('text_newer', esc_html__( 'Newer Posts', 'hotsugar')).'</span><i class="ion-ios-arrow-thin-left"></i>');
            echo '</div>';
        echo '</div>';
    }elseif($type == 'number' && 1 != $pages){
        $big = 9999; // need an unlikely integer
        echo "<div class='tw-pagination tw-meta clearfix'>";
        $pagination = paginate_links(
            array(
                'base' => str_replace($big, '%#%', esc_url(get_pagenum_link($big))),
                'end_size' => 3,
                'mid_size' => 6,
                'format' => '?paged=%#%',
                'current' => max(1, get_query_var('paged')),
                'total' => $wp_query->max_num_pages,
                'type' => 'list',
                'prev_text' => hotsugar_option('text_prev', esc_html__( 'Prev', 'hotsugar')),
                'next_text' => hotsugar_option('text_next', esc_html__( 'Next', 'hotsugar')),
            )
        );
        echo balanceTags($pagination);
        echo "</div>";
    }elseif($type == 'infinite' && 1 != $pages){
        wp_enqueue_script('waypoints');
        echo '<div class="tw-pagination tw-infinite-scroll tw-hover tw-meta" data-has-next="' . ($paged === $pages ? 'false' : 'true') . '">';
        echo '<span class="loading"><img src="' . esc_url(HOTSUGAR_DIR . 'assets/img/loading-bubbles.svg') . '" alt="'.esc_html__('Loading Posts...', 'hotsugar').'" /></span>';
        echo '<div class="older"><a class="next" href="' . esc_url(get_pagenum_link($paged + 1)) . '"><span>'.hotsugar_option('text_loadmore', esc_html__( 'Load More', 'hotsugar')).'</span><i class="ion-ios-arrow-down"></i></a></div>';
        echo '</div>';
    }
}

function hotsugar_get_image_by_id($id,$url=false,$size='full'){
    $lrg_img=wp_get_attachment_image_src($id,$size);
    $output='';
    if(isset($lrg_img[0])){
        if($url){
            $output.=$lrg_img[0];
        }else{
            $output.='<img src="'.esc_url($lrg_img[0]).'" />';
        }
    }
    return $output;
}

if (!function_exists('hotsugar_image')) {
    function hotsugar_image($size = 'full', $returnURL = false) {
        global $post;
        $attachment = get_post(get_post_thumbnail_id($post->ID));
        if(!empty($attachment)){
            if ($returnURL) {
                $lrg_img = wp_get_attachment_image_src($attachment->ID, $size);
                $url = $lrg_img[0];
                $alt0 = get_post_meta($attachment->ID, '_wp_attachment_image_alt', true);
                $alt = empty($alt0)?$attachment->post_title:$alt0;
                $img['url'] = $url;
                $img['alt'] = $alt;
                return $img;
            } else {
                return get_the_post_thumbnail($post->ID,$size);
            }
        }
    }
}

if (!function_exists('hotsugar_single_title')) {
    function hotsugar_single_title(){
        if(hotsugar_option('single_cats', true)){
            echo '<div class="entry-cats">'.hotsugar_cats().'</div>';
        }
        echo '<h1 class="entry-title">'.get_the_title().'</h1>';
        if(hotsugar_option('single_meta', true)){
            echo '<div class="entry-date tw-meta">'.get_the_time(get_option('date_format')).' / <span class="entry-author">'.esc_html__('By', 'hotsugar').'&nbsp;';
            the_author_posts_link();  
            echo '</span></div>';
        }
    }
}

if (!function_exists('hotsugar_author')) {
    function hotsugar_author(){ 
        $description = get_the_author_meta('description');
        if ($description != ''){ ?>
        <div class="tw-author">
            <div class="author-box">
                <?php
                $tw_author_email = get_the_author_meta('email');
                echo get_avatar($tw_author_email, $size = '120');
                ?>
                <h3><?php
                    if (is_author()){
                        the_author();
                    }else{
                        the_author_posts_link();
                    } ?>
                </h3>
                <?php
                echo '<span class="tw-meta">'.esc_html__('writer', 'hotsugar').'</span>';
                echo '<p>';
                    echo esc_html($description);
                echo '</p>';
                $socials = get_the_author_meta('user_social');
                if(!empty($socials)){
                    echo '<div class="entry-share">';
                    $social_links=explode("\n",$socials);
                    foreach($social_links as $social_link){
                        $icon = hotsugar_social_icon(esc_url($social_link));
                        echo '<a href="'.esc_url($social_link).'"><i class="'.esc_attr($icon).'"></i></a>';
                    }
                    echo '</div>';
                } ?>
            </div>
        </div><?php
        }
    }
}

if (!function_exists('hotsugar_comment_form')) {
    function hotsugar_comment_form($fields) {
        global $id, $post_id;
        if (null === $post_id)
            $post_id = $id;
        else
            $id = $post_id;

        $commenter = wp_get_current_commenter();
        $req = get_option('require_name_email');
        $aria_req = ( $req ? " aria-required='true'" : '' );

        $fields = array(
            'author' => '<p class="comment-form-author">' .
            '<input id="author" name="author" placeholder="' . esc_html__('Name *', 'hotsugar') . '" type="text" value="' . esc_attr($commenter['comment_author']) . '" size="30"' . $aria_req . ' />' . '</p>',
            'email' => '<p class="comment-form-email">' .
            '<input id="email" name="email" placeholder="' . esc_html__('Email *', 'hotsugar') . '" type="text" value="' . esc_attr($commenter['comment_author_email']) . '" size="30"' . $aria_req . ' />' . '</p>',
            'url' => '<p class="comment-form-url">' .
            '<input id="url" name="url" placeholder="' . esc_html__('Website', 'hotsugar') . '" type="text" value="' . esc_attr($commenter['comment_author_url']) . '" size="30" />' . '</p><div class="clearfix"></div>',
        );
        return $fields;
    }
    add_filter('comment_form_default_fields', 'hotsugar_comment_form');
}

if (!function_exists('hotsugar_comment')) {
    function hotsugar_comment($comment, $args, $depth){
        $GLOBALS['comment'] = $comment;?>
        <div <?php comment_class();?> id="comment-<?php comment_ID(); ?>">
            <div class="comment-author">
                <?php echo get_avatar($comment, $size = '60'); ?>
            </div>
            <div class="comment-text">
                <h3 class="author"><?php echo get_comment_author_link(); ?></h3>
                <span class="entry-date tw-meta"><?php echo get_comment_date('F j, Y'); ?></span>
                <p class="reply tw-meta"><?php comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></p>
                <?php comment_text() ?>
            </div><?php
    }
}

if (!function_exists('hotsugar_comment_count')) {
    function hotsugar_comment_count() {
        if (comments_open()) {
            $comment_count = get_comments_number('0', '1', '%');
            if ($comment_count == 0) {
                $comment_trans = esc_html__('no comment', 'hotsugar');
            } elseif ($comment_count == 1) {
                $comment_trans = esc_html__('1 comment', 'hotsugar');
            } else {
                $comment_trans = $comment_count . ' ' . esc_html__('comments', 'hotsugar');
            }
            return "<a href='" . esc_url(get_comments_link()) . "' title='" . esc_attr($comment_trans) . "' class='comment-count'><i class='ion-chatbubbles'></i><span>" . esc_html($comment_trans) . "</span></a>";
        }
    }
}
function hotsugar_cats($sep = ', '){
    $cats = '';
    foreach((get_the_category()) as $category) {
        $options = get_option("taxonomy_".$category->cat_ID);
        if (!isset($options['featured']) || !$options['featured']){
            $cats .= '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( 'View all posts in %s', 'hotsugar' ), $category->name ) . '" ' . '>'  . $category->name.'</a><span>'.$sep.'</span>';
        }
    }
    if(!$cats && is_search()){
        $cats = '<a href="' . get_permalink() . '">' . esc_html__('Page', 'hotsugar') . '</a>';
    }
    return $cats;
}
if (!function_exists('hosugar_categories_postcount')){
	function hosugar_categories_postcount($variable) {
		$pos = strpos($variable, '<option');
		if (!$pos) {
			$variable = str_replace('(', '<span class="post-count">(', $variable);
			$variable = str_replace(')', ')</span>', $variable);
		}
		return $variable;
	}
}
add_filter('wp_list_categories', 'hosugar_categories_postcount');
add_filter('get_archives_link', 'hosugar_categories_postcount');

if (!function_exists('hotsugar_post_share')) {
    function hotsugar_post_share() {
        $output = '<div class="tw_post_sharebox clearfix">';
            $output .= '<span class="share-text">'.esc_html__('Share this Post', 'hotsugar').'</span>';
            $post_title = get_the_title();
            $output .= '<div class="sharebox-icons">';
                $output .= '<div class="googleplus-share"><a href="' . esc_url(get_permalink()) . '" title="Share this"><i class="ion-social-googleplus"></i></a></div>';
                $output .= '<div class="twitter-share"><a href="' . esc_url(get_permalink()) . '" title="Tweet" data-title="' . esc_attr($post_title) . '"><i class="ion-social-twitter"></i></a></div>';
                $output .= '<div class="facebook-share"><a href="' . esc_url(get_permalink()) . '" title="Share this"><i class="ion-social-facebook"></i></a></div>';
            $output .= '</div>';
        $output .= '</div>';
        echo balanceTags($output);
    }
}

if(!function_exists('hotsugar_origshare_count')){
    function hotsugar_origshare_count($socials = array('facebook', 'twitter', 'pinterest')){
        $count = 0;
        foreach($socials as $social){
            if($social == 'facebook'){
                $url = get_permalink();
                $contents=false;
                try {
                    $contents = wp_remote_get('http://graph.facebook.com/?id='.$url);
                } catch(Exception $e) {
                    $s_count = 0;
                }
                if(is_array($contents)&&isset($contents['body'])) {
                        $json = json_decode($contents['body']);
                        $s_count = isset($json->share->share_count) ? $json->share->share_count : 0;
                } else {
                        $s_count = 0;
                }
            } elseif($social == 'pinterest') {
                $contents=false;
                $url = get_permalink();
                try {
                    $contents = wp_remote_get('http://widgets.pinterest.com/v1/urls/count.json?source=6&url='.$url);
                } catch(Exception $e) {
                    $s_count = 0;
                }
                if(is_array($contents)&&isset($contents['body'])) {
                        $contents['body']=str_replace(array('receiveCount(',')'),'',$contents['body']);
                        $json = json_decode($contents['body']);
                        $s_count = isset($json->count) ? $json->count : 0;
                } else {
                        $s_count = 0;
                }
            } elseif($social == 'twitter'){
                global $post;
                $s_count = get_post_meta($post->ID, 'post_twitter', true);
            }
            $count += intval($s_count, 10);
        }
        return $count;
    }
}

if (!function_exists('hotsugar_share_count')){

    function hotsugar_share_count($socials = array('facebook', 'twitter', 'pinterest')){
        global $post;       
        $count = 0;
        foreach($socials as $social){
            $s_count = get_post_meta($post->ID, 'post_' . $social, true);
            $count += intval($s_count, 10);
        }
        return intval($count, 10);
    }

}
if (isset($_REQUEST['social_pid']) && isset($_REQUEST['social_name'])){
    $pid = intval($_REQUEST['social_pid']);
    update_post_meta($pid, 'post_' . $_REQUEST['social_name'], get_post_meta($pid, 'post_' . $_REQUEST['social_name'], true) + 1);
    die;
}

function hotsugar_social_link($social){
    if(!empty($social)){
        $icon = hotsugar_social_icon(esc_url($social));
        return '<a href="'.esc_url($social).'"><i class="'.esc_attr($icon).'"></i></a>';
    }    
}

function hotsugar_social_name($url){
    if(strpos($url,'twitter.com') > -1) { return 'twitter';}
    if(strpos($url,'linkedin.com') > -1){ return 'linkedin';}
    if(strpos($url,'facebook.com') > -1){ return 'facebook';}
    if(strpos($url,'delicious.com') > -1){ return 'delicious';}
    if(strpos($url,'codepen.io') > -1){ return 'codepen';}
    if(strpos($url,'github.com') > -1){ return 'github';}
    if(strpos($url,'wordpress.org') > -1 || strpos($url,'wordpress.com') > -1){ return 'wordpress';}
    if(strpos($url,'youtube.com') > -1){ return 'youtube';}
    if(strpos($url,'behance.net') > -1){ return 'behance';}
    if(strpos($url,'pinterest.com') > -1){ return 'pinterest';}
    if(strpos($url,'foursquare.com') > -1){ return 'foursquare';}
    if(strpos($url,'soundcloud.com') > -1){ return 'soundcloud';}
    if(strpos($url,'dribbble.com') > -1){ return 'dribbble';}
    if(strpos($url,'instagram.com') > -1){ return 'instagram';}
    if(strpos($url,'plus.google') > -1){ return 'googleplus';}
    if(strpos($url,'vine.co') > -1){ return 'vine';}
    if(strpos($url,'twitch.tv') > -1){ return 'twitch';}
    if(strpos($url,'tumblr.com') > -1){ return 'tumblr';}
    if(strpos($url,'trello.com') > -1){ return 'trello';}
    if(strpos($url,'spotify.com') > -1){ return 'spotify';}
    
    return 'link';
}
function hotsugar_social_icon($url){
    if(strpos($url,'twitter.com') > -1) { return 'ion-social-twitter';}
    if(strpos($url,'linkedin.com') > -1){ return 'ion-social-linkedin';}
    if(strpos($url,'facebook.com') > -1){ return 'ion-social-facebook';}
//    if(strpos($url,'delicious.com')){ return 'fa-delicious';}
    if(strpos($url,'codepen.io') > -1){ return 'ion-social-codepen';}
    if(strpos($url,'github.com') > -1){ return 'ion-social-github';}
    if(strpos($url,'wordpress.org') > -1 || strpos($url,'wordpress.com') > -1){ return 'ion-social-wordpress';}
    if(strpos($url,'youtube.com') > -1){ return 'ion-social-youtube';}
//    if(strpos($url,'behance.net')){ return 'fa-behance';}
    if(strpos($url,'pinterest.com') > -1){ return 'ion-social-pinterest';}
    if(strpos($url,'foursquare.com') > -1){ return 'ion-social-foursquare';}
//    if(strpos($url,'soundcloud.com')){ return 'fa-soundcloud';}
    if(strpos($url,'dribbble.com') > -1){ return 'ion-social-dribbble';}
    if(strpos($url,'instagram.com') > -1){ return 'ion-social-instagram';}
    if(strpos($url,'plus.google') > -1){ return 'ion-social-googleplus';}
//    if(strpos($url,'vine.co')){ return 'fa-vine';}
    if(strpos($url,'twitch.tv') > -1){ return 'ion-social-twitch';}
    if(strpos($url,'tumblr.com') > -1){ return 'ion-social-tumblr';}
    if(strpos($url,'apple.com') > -1){ return 'ion-social-apple';}
    if(strpos($url,'google.com') > -1){ return 'ion-social-android';}
    if(strpos($url,'microsoft.com') > -1){ return 'ion-social-windows';}
//    if(strpos($url,'spotify.com')){ return 'fa-spotify';}
    
    return 'ion-link';
}
function hotsugar_social_name_from_url($social_link,$option){
    return trim(str_replace(array_merge(array('https:','http:','www.','/'),$option), '',$social_link));
}
function hotsugar_social_button($social_link,$settings){
    ob_start();
        $permalink=get_the_permalink();
        $social_name=hotsugar_social_name($social_link);
        if(empty($settings['speed'])){
            switch($social_name){
                case'facebook':{ ?>
                    <div id="fb-root"></div>
                    <script>
                        (function(d, s, id) {
                            var js, fjs = d.getElementsByTagName(s)[0];
                            if (d.getElementById(id)) return;
                            js = d.createElement(s); js.id = id;
                            js.src = "//connect.facebook.net/en_US/sdk.js#xfbml=1&version=v2.5";
                            fjs.parentNode.insertBefore(js, fjs);
                        }(document, 'script', 'facebook-jssdk'));
                    </script>
                    <div class="fb-like" data-href="<?php echo esc_url($social_link); ?>" data-layout="button_count" data-action="like" data-show-faces="true" data-share="false"></div><?php
                    break;
                }
                case'twitter':{
                    $twt_via=hotsugar_social_name_from_url($social_link,array('twitter.com')); ?>
                    <a href="https://twitter.com/<?php echo esc_attr($twt_via); ?>" class="twitter-follow-button" data-show-count="false"><?php esc_attr_e('Follow ','hotsugar'); echo esc_attr('@'.$twt_via); ?></a>
                    <script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0],p=/^http:/.test(d.location)?'http':'https';if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src=p+'://platform.twitter.com/widgets.js';fjs.parentNode.insertBefore(js,fjs);}}(document, 'script', 'twitter-wjs');</script><?php
                    break;
                }
                case'instagram':{
                    $insta_name=hotsugar_social_name_from_url($social_link,array('instagram.com')); ?>
                    <a href="<?php echo esc_url($social_link); ?>" target="_blank"><img src="<?php echo esc_url(HOTSUGAR_DIR.'assets/img/tab-link.png'); ?>" alt="<?php echo esc_html__('Follow Instragram','hotsugar'); ?>" /></a>
                    <?php
                    break;
                }
                case'pinterest':{ ?>
                    <a data-pin-do="buttonFollow" href="<?php echo esc_url($social_link); ?>"><?php echo esc_html__('Follow','hotsugar'); ?></a>
                    <script async defer src="//assets.pinterest.com/js/pinit.js"></script><?php
                    break;
                }
                case'googleplus':{ ?>
                    <script src="https://apis.google.com/js/platform.js" async defer></script>
                    <div class="g-follow" data-annotation="bubble" data-height="20" data-href="<?php echo esc_url($social_link); ?>" data-rel="author"></div><?php
                    break;
                }
                case'youtube':{
                    $ydata=' data-channelid="'.hotsugar_social_name_from_url($social_link,array('youtube.com','channel')).'"';
                    if(strpos($social_link,'/user/')){
                        $ydata=' data-channel="'.hotsugar_social_name_from_url($social_link,array('youtube.com','user')).'"';
                    }
                    $ybtn='<div class="g-ytsubscribe"'.$ydata.' data-layout="default" data-count="default"></div>'; ?>
                    <script src="https://apis.google.com/js/platform.js"></script><?php
                    echo wp_kses($ybtn,array('div' => array('class' => array(),'data-channelid' => array(),'data-channel' => array(),'data-layout' => array(),'data-count' => array())));
                    break;
                }
                default :{
                    echo '<a href="'.esc_url($social_link).'">'.esc_html($social_name).'</a>';
                }
            }
        }else{
            $imgSrc='';
            switch($social_name){
                case'facebook'  :{$imgSrc='tab-facebook.png';break;}
                case'twitter'   :{$imgSrc='tab-twitter.png';break;}
                case'pinterest' :{$imgSrc='tab-pinterest.png';break;}
                case'googleplus':{$imgSrc='tab-google.png';break;}
                case'youtube'   :{$imgSrc='tab-youtube.png';break;}
                default         :{$imgSrc='tab-link.png';break;}
            }
            echo '<a href="'.esc_url($social_link).'" target="_blank"><img src="'.esc_url(HOTSUGAR_DIR.'assets/img/'.$imgSrc).'" alt="'.$social_name.'" /></a>';
        }
    return ob_get_clean();
}
function hotsugar_social_icons(){
    $socials = hotsugar_option("socials");
    if(!empty($socials)){
        $output = '<div class="social-icons">';
        foreach($socials as $social){ $output .= hotsugar_social_link($social); }
        $output .= '</div>';
        return $output;
    }
}

function hotsugar_footer_socials($sub = false){
    $socials = hotsugar_option("socials");
    if(!empty($socials)){
        $output = '<div class="entry-share clearfix">';
        if($sub){
            foreach($socials as $social){ 
                if(!empty($social['href']) && !empty($social['name'])){
                    $icon = hotsugar_social_icon(esc_url($social['href']));
                    $text = !empty($social['subtext'])  ? ('</span><span>'.esc_attr($social['subtext'])) : '';
                    $output .= '<div class="social-item"><a class="tw-meta" href="'.esc_url($social['href']).'"><i class="'.esc_attr($icon).'"></i><span>'.esc_attr($social['name']).$text.'</span></a></div>';
                }     
            }
        } else {
            foreach($socials as $social){ 
                if(!empty($social['href']) && !empty($social['name'])){
                    $icon = hotsugar_social_icon(esc_url($social['href']));
                    $output .= '<div class="social-item"><a class="tw-meta '.str_replace('ion-', '', esc_attr($icon)).'" href="'.esc_url($social['href']).'"><i class="'.esc_attr($icon).'"></i><span>'.esc_attr($social['name']).'</span></a></div>';
                }     
            }
        }
        
        $output .= '</div>';
        return $output;
    }
}

function hotsugar_related_posts() {
    global $post;
    
    $categories = get_the_category($post->ID);
    
    if ($categories) {
        $category_ids = array();

	foreach($categories as $individual_category) $category_ids[] = $individual_category->term_id;
	
	$args = array(
		'category__in'     => $category_ids,
		'post__not_in'     => array($post->ID),
		'posts_per_page'   => 3, // Number of related posts that will be shown.
		'ignore_sticky_posts' => 1,
		'orderby' => 'rand'
	);
        $atts['img_size'] = 'recent_post';
        $my_query = new WP_Query( $args );
	if( $my_query->have_posts() ) { ?>
            <div class="related-posts">
                <h4 class="np-title-line"><?php esc_html_e('Related posts', 'hotsugar'); ?></h4>
                <div class="row">
		<?php while( $my_query->have_posts() ) {
			$my_query->the_post();?>
                        <div class="col-md-4">
                            <div class="related-item">
                                <h3><a href="<?php echo get_permalink(); ?>"><?php the_title(); ?></a></h3>
                                <span class="entry-date"><?php the_time( get_option('date_format') ); ?></span>
                                <?php 
                                    if(!($thumb = hotsugar_standard_media($post, $atts))){
                                        $pformat = get_post_format() == "" ? "standard" : get_post_format();
                                        $thumb = '<div class="entry-media"><div class="format-icon '.esc_attr($pformat).'"></div></div>';
                                    }
                                    echo balanceTags($thumb);
                                ?>
                            </div>
                        </div>
		<?php
		}
		echo '</div>';
            echo '</div>';
            wp_reset_postdata();
	}
    }
}

function hotsugar_seen_add(){
    global $post;
    $seen = get_post_meta($post->ID,'post_seen',true);
    $seen = intval($seen)+1;
    update_post_meta($post->ID,'post_seen',$seen);
}
function hotsugar_seen_count(){
    global $post;
    $seen = get_post_meta($post->ID,'post_seen',true);
    return (empty($seen)?0:$seen);    
}

// Hex To RGB
function hotsugar_hex2rgb($hex) {
    $hex = str_replace("#", "", $hex);

    if (strlen($hex) == 3) {
        $r = hexdec(substr($hex, 0, 1) . substr($hex, 0, 1));
        $g = hexdec(substr($hex, 1, 1) . substr($hex, 1, 1));
        $b = hexdec(substr($hex, 2, 1) . substr($hex, 2, 1));
    } else {
        $r = hexdec(substr($hex, 0, 2));
        $g = hexdec(substr($hex, 2, 2));
        $b = hexdec(substr($hex, 4, 2));
    }
    $rgb = array($r, $g, $b);
    return implode(",", $rgb); // returns the rgb values separated by commas
}

add_filter( 'wp_get_attachment_image_attributes', 'hotsugar_image_attr',10,3);
function hotsugar_image_attr($attr,$attachment,$size){
    global $_wp_additional_image_sizes;
    if (!empty($attachment->post_mime_type) && $attachment->post_mime_type === 'image/gif' && isset($attachment->guid)){
        $width=$height=0;
        if(is_array($size)){
            list($width,$height)=$size;
        }elseif(is_string($size)&&isset($_wp_additional_image_sizes[$size])){
            $width=$_wp_additional_image_sizes[$size]['width'];
            $height=$_wp_additional_image_sizes[$size]['height'];
        }else{
            $width =get_option($size.'_size_w');
            $height=get_option($size.'_size_h');
        }
        $attr['data-animated_src'] = $attachment->guid;
        $attr['data-width']  = $width;
        $attr['data-height'] = $height;
        $attr['onload'] = 'loadGifImage(this)';
        $attr['class'].=' hotsugar-gif';        
        if($attr['src']===$attachment->guid){
            $img=wp_get_attachment_image_src($attachment->ID,'thumb');
            if(isset($img[0])){
                $attr['src']=$img[0];
            }
        }
    }
    return $attr;
}