<?php

/**
 * Initialize the custom Meta Boxes. 
 */
add_action('admin_init', 'hotsugar_page_options');

function hotsugar_page_options() {
    
    $categories = get_categories("hide_empty=0&parent=0");
    $cats = array("0" => esc_html__("All Category", 'hotsugar'));
    if (!empty($categories)) {
        foreach ($categories as $category) {
            $cats[$category->slug] = $category->name;
        }
    }
    
    $blog_layouts = array(
        'simple' => array('text'=>esc_html__('Simple', 'hotsugar'),'src'=>esc_url(HOTSUGAR_DIR . 'assets/img/blog_simple.png')),
        'grid' => array('text'=>esc_html__('Grid', 'hotsugar'),'src'=>esc_url(HOTSUGAR_DIR . 'assets/img/blog_grid.png')),
        'masonry' => array('text'=>esc_html__('Masonry', 'hotsugar'),'src'=>esc_url(HOTSUGAR_DIR . 'assets/img/blog_masonry.png')),
        'list' => array('text'=>esc_html__('List', 'hotsugar'),'src'=>esc_url(HOTSUGAR_DIR . 'assets/img/blog_list.png')),
        'list2' => array('text'=>esc_html__('List right thumb', 'hotsugar'),'src'=>esc_url(HOTSUGAR_DIR . 'assets/img/blog_list2.png')),
    );

    $page_options = array(
        Array(
            'name' => esc_html__('Select slider layout?', 'hotsugar'),
            'id' => 'slider',
            'std' => '',
            'type' => 'layout',
            'options'=>array(
                '' => array(
                    'title' => esc_html__('Slider None', 'hotsugar'),
                    'img' => HOTSUGAR_DIR . 'assets/img/slider_empty.png'
                ),
                'slider1' => array(
                    'title' => esc_html__('Slider 1', 'hotsugar'),
                    'img' => HOTSUGAR_DIR . 'assets/img/slider_1.png'
                ),
                'slider2' => array(
                    'title' => esc_html__('Slider 2', 'hotsugar'),
                    'img' => HOTSUGAR_DIR . 'assets/img/slider_2.png'
                ),
                'slider3' => array(
                    'title' => esc_html__('Slider 3', 'hotsugar'),
                    'img' => HOTSUGAR_DIR . 'assets/img/slider_3.png'
                ),
                'slider4' => array(
                    'title' => esc_html__('Slider 4', 'hotsugar'),
                    'img' => HOTSUGAR_DIR . 'assets/img/slider_4.png'
                ),
                'slider5' => array(
                    'title' => esc_html__('Slider 5', 'hotsugar'),
                    'img' => HOTSUGAR_DIR . 'assets/img/slider_5.png'
                ),
                'custom' => array(
                    'title' => esc_html__('Custom shortcode', 'hotsugar'),
                    'img' => HOTSUGAR_DIR . 'assets/img/custom_option.png'
                )
            ),
        ),
        Array(
            'name' => esc_html__('Select category?', 'hotsugar'),
            'id' => 'slider_cat',
            'std' => '',
            'type' => 'select',
            'options'=> $cats,
            'dependency' => array(
                'element' => 'slider',
                'value' => array('slider1', 'slider2', 'slider3', 'slider4', 'slider5'),
            ),
        ),
        Array(
            'name' => esc_html__('Slider Post Count?', 'hotsugar'),
            'id' => 'slider_post_count',
            'std' => '',
            'placeholder' => esc_html__('Insert only Digits here', 'hotsugar'),
            'type' => 'text',
            'dependency' => array(
                'element' => 'slider',
                'value' => array('slider1', 'slider2', 'slider3', 'slider4', 'slider5'),
            ),
        ),
        Array(
            'name' => esc_html__('Custom shortcode?', 'hotsugar'),
            'id' => 'slider_shortcode',
            'std' => '',
            'placeholder' => esc_html__('Example: [revslider id="3"]', 'hotsugar'),
            'type' => 'text',
            'dependency' => array(
                'element' => 'slider',
                'value' => array('custom'),
            ),
        ),
        Array(
            'name' => esc_html__('Blog Layout', 'hotsugar'),
            'id' => 'blog_layout',
            'std' => '',
            'desc' => esc_html__('Choose Row and Add Row and assign Row Layout, You can also Delete! Note: If you selected All Categories then only 1 Row will enough and delete the other styles.', 'hotsugar'),
            'type' => 'blog',
            'options'=>array(
                'layout' => $blog_layouts,
                'cats' => $cats,
                'posts_per_page' => '',
                'excerpt' => '',
                'sidebar' => array('false' => 'False', 'true' => 'True'),
                'pagination' => array('none' => 'None', 'simple' => 'Simple', 'number' => 'Numbered', 'infinite' => 'Infinite'),
            )
        ),
    );
    
    
    add_meta_box('page_meta_settings', esc_html__('Page settings', 'hotsugar'), 'hotsugar_postmetabox', 'page', 'normal', 'core', $page_options);

}
