<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {return;}

    // This is your option name where all the Redux data is stored.
    $opt_name = "hotsugar_redux";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => false,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__( 'Theme Options', 'hotsugar'),
        'page_title'           => esc_html__( 'Theme Options', 'hotsugar'),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );
    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> START Basic Fields
    $options_general=array(
        array(
            'id'       => 'theme_layout',
            'type'     => 'select',
            'title'    => esc_html__( 'Theme layout', 'hotsugar' ),
            'subtitle' => esc_html__( 'Your site will be Fullwidth or Boxed layout and If you want to edit background then Check the Color options.', 'hotsugar' ),
            'options'  => array(
                'full' => 'Full width',
                'boxed' => 'Boxed',
            ),
            'default'  => 'full'
        ),
        array(
            'id'       => 'boxed_bg',
            'required' => array( 'theme_layout', '=', 'boxed' ),
            'type'     => 'background',
            'title'    => esc_html__( 'Background options', 'hotsugar' ),
            'subtitle' => esc_html__( 'Your site will be Fullwidth or Boxed layout and If you want to edit background then Check the Color options.', 'hotsugar' ),
            'default'  => ''
        ),
        array(
            'id'       => 'header_layout',
            'type'     => 'select',
            'title'    => esc_html__( 'Header layout', 'hotsugar' ),
            'options'  => array(
                '' => 'Simple',
                '2' => 'Minimal',
            ),
            'default'  => ''
        ),
        array(
            'id'       => 'logo',
            'type'     => 'media',
            'url'      => true,
            'title'    => esc_html__( 'Upload Your Logo', 'hotsugar'),
            'subtitle' => esc_html__( 'If no Logo Uploaded then Your Site Name will display your Logo section, Edit this option Settings -> General Tab', 'hotsugar'),
            'compiler' => 'true',
            'desc'     => '',
            'default'  => '',
        ),
        array(
            'id'       => 'favicon',
            'type'     => 'media',
            'url'      => true,
            'title'    => esc_html__( 'Upload Your Favicon', 'hotsugar'),
            'subtitle' => esc_html__( 'Default Fav icon is located in our hotsugar/assets/img/favicon.ico', 'hotsugar'),
            'compiler' => 'true',
            'desc'     => '',
            'default'  => '',
        ),
        array(
            'id'       => 'header_height',
            'type'     => 'text',
            'title'    => esc_html__( 'Header menu height (px)?', 'hotsugar'),
            'default'  => '50',

        ),
        array(
            'id'       => 'slider_height',
            'type'     => 'text',
            'title'    => esc_html__( 'Fullwidth slider height (px)?', 'hotsugar'),
            'subtitle' => esc_html__( 'While the building the Row builder if you enabled the Slider Layout 1 and 2 then this option will control the height', 'hotsugar'),
            'default'  => '600',
        ),
        array(
            'id'       => 'slider_auto',
            'type'     => 'switch',
            'title'    => esc_html__( 'Slider Auto Play?', 'hotsugar'),
            'subtitle' => esc_html__( 'Slider Auto Play?', 'hotsugar'),
            'default'  => 0,
        ),
        array(
            'id'       => 'slider_delay',
            'type'     => 'text',
            'title'    => esc_html__( 'Slider Delay?', 'hotsugar'),
            'subtitle' => esc_html__( 'Slider Delay?', 'hotsugar'),
            'default'  => '3000',
            'required' => array( 'slider_auto', '=', 1 ),
        ),
        array(
            'id'       => 'scroll_menu',
            'type'     => 'switch',
            'title'    => esc_html__( 'Scroll Up Menu?', 'hotsugar'),
            'subtitle'    => esc_html__( 'If you scroll up while scrolling down menu there has an Our menu is displayed and you can disable it', 'hotsugar'),
            'default'  => 1,

        ),
        array(
            'id'       => 'instagram_position',
            'type'     => 'select',
            'title'    => esc_html__( 'Instagram position', 'hotsugar' ),
            'subtitle' => esc_html__( 'Your site will be Fullwidth or Boxed layout and If you want to edit background then Check the Color options.', 'hotsugar' ),
            'options'  => array(
                '' => 'None',
                'header' => 'Header',
                'footer' => 'Footer',
            ),
            'default'  => ''
        ),
        array(
            'id'       => 'instagram_username',
            'required' => array( 'instagram_position', '!=', '' ),
            'type'     => 'text',
            'title'    => esc_html__( 'Instagram username?', 'hotsugar'),
            'subtitle' => esc_html__( 'Header area Height option and if you inserted big Logo then this option will need to increase', 'hotsugar'),
            'default'  => '',

        ),
    );
    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'General', 'hotsugar'),
        'id'               => 'general',
        'customizer_width' => '400px',
        'icon'             => 'el el-home',
        'fields'           => $options_general
    ) );
    
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Blog', 'hotsugar'),
        'id'         => 'blog',
        'icon'       => 'el el-pencil',
        'fields'     => array(
            array(
                'id'=>'blog-section-start',
                'type' => 'section',
                'title' => esc_html__('General Blog Pages & Categories Options', 'hotsugar'),
                'indent' => true // Indent all options below until the next 'section' option is set.
                ),
                array(
                    'id'       => 'blog_layout',
                    'type'     => 'image_select',
                    'title'    => esc_html__( 'Set Blog Layout', 'hotsugar'),
                    'subtitle' => esc_html__( 'You can set the Normal, Large Media or Fullwidth. You can override it on Blog Single section', 'hotsugar'),
                    'options'  => array(
                            'simple' => array(
                                'alt' => esc_html__('Featured area small', 'hotsugar'),
                                'title' => esc_html__('Featured area small', 'hotsugar'),
                                'img' => HOTSUGAR_DIR . 'assets/img/blog_simple.png'
                            ),
                            'grid' => array(
                                'alt' => esc_html__('Featured area fullwidth', 'hotsugar'),
                                'title' => esc_html__('Featured area fullwidth', 'hotsugar'),
                                'img' => HOTSUGAR_DIR . 'assets/img/blog_grid.png'
                            ),
                            'masonry' => array(
                                'alt' => esc_html__('Featured area fullwidth', 'hotsugar'),
                                'title' => esc_html__('Featured area fullwidth', 'hotsugar'),
                                'img' => HOTSUGAR_DIR . 'assets/img/blog_masonry.png'
                            ),
                            'list' => array(
                                'alt' => esc_html__('Featured area fullwidth', 'hotsugar'),
                                'title' => esc_html__('Featured area fullwidth', 'hotsugar'),
                                'img' => HOTSUGAR_DIR . 'assets/img/blog_list.png'
                            ),
                            'list2' => array(
                                'alt' => esc_html__('Featured area fullwidth', 'hotsugar'),
                                'title' => esc_html__('Featured area fullwidth', 'hotsugar'),
                                'img' => HOTSUGAR_DIR . 'assets/img/blog_list2.png'
                            )
                        ),
                    'default'  => 'list',
                ),
                array(
                    'id'       => 'blog_sidebar',
                    'type'     => 'select',
                    'title'    => esc_html__( 'Blog sidebar', 'hotsugar' ),
                    'subtitle' => esc_html__( 'Have a Sidebar ?', 'hotsugar' ),
                    'options'  => array(
                        'true' => 'True',
                        'false' => 'False',
                    ),
                    'default'  => 'true'
                ),
                array(
                    'id'       => 'blog_excerpt',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Blog excerpt?', 'hotsugar' ),
                    'subtitle' => esc_html__( 'Excerpt word count', 'hotsugar' ),
                    'default'  => ''
                ),
                array(
                    'id'       => 'blog_pagination',
                    'type'     => 'select',
                    'title'    => esc_html__( 'Blog pagination', 'hotsugar' ),
                    'subtitle' => esc_html__( 'Pagination type ?', 'hotsugar' ),
                    'options'  => array(
                        'simple' => 'Simple',
                        'number' => 'Numbered',
                        'infinite' => 'Infinite',
                        'none' => 'None',
                    ),
                    'default'  => 'simple'
                ),
                array(
                    'id'       => 'gif_auto_blog',
                    'type'     => 'switch',
                    'title'    => esc_html__( 'GIF auto play on Row Builder?', 'hotsugar'),
                    'subtitle'     => esc_html__( 'Gif can autoplay or Play Button on Homepage.', 'hotsugar'),
                    'default'  => 1,
                ),
            array(
                'id'=>'blog-section-end',
                'type' => 'section', 
                'indent' => false // Indent all options below until the next 'section' option is set.
            ),
            array(
                'id'=>'blog-single-start',
                'type' => 'section',
                'title' => esc_html__('Blog Single Options', 'hotsugar'),
                'indent' => true // Indent all options below until the next 'section' option is set.
                ),
                array(
                'id'       => 'single_layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Set Blog Single Layout', 'hotsugar'),
                'subtitle' => esc_html__( 'You can set the Normal, Large Media or Fullwidth. You can override it on Blog Single section', 'hotsugar'),
                'options'  => array(
                        'right-sidebar' => array(
                            'alt' => esc_html__('Right Sidebar', 'hotsugar'),
                            'title' => esc_html__('Right Sidebar', 'hotsugar'),
                            'img' => HOTSUGAR_DIR . 'assets/img/single_rightsidebar.png'
                        ),
                        'left-sidebar' => array(
                            'alt' => esc_html__('Left Sidebar', 'hotsugar'),
                            'title' => esc_html__('Left Sidebar', 'hotsugar'),
                            'img' => HOTSUGAR_DIR . 'assets/img/single_leftsidebar.png'
                        ),
                        'fullwidth-content' => array(
                            'alt' => esc_html__('Fullwidth Content', 'hotsugar'),
                            'title' => esc_html__('Fullwidth Content', 'hotsugar'),
                            'img' => HOTSUGAR_DIR . 'assets/img/single_fullwidth.png'
                        ),
                        'narrow-content' => array(
                            'alt' => esc_html__('Narrow Content', 'hotsugar'),
                            'title' => esc_html__('Narrow Content', 'hotsugar'),
                            'img' => HOTSUGAR_DIR . 'assets/img/single_narrow.png'
                        )
                    ),
                    'default'  => 'right-sidebar',
                    ),
                    array(
                        'id'       => 'single_media',
                        'type'     => 'image_select',
                        'title'    => esc_html__( 'Single media layout', 'hotsugar' ),
                        'subtitle' => esc_html__( 'You can override it on Blog Single section', 'hotsugar' ),
                        'options'  => array(
                            'small' => array(
                                'alt' => esc_html__('Featured area small', 'hotsugar'),
                                'title' => esc_html__('Featured area small', 'hotsugar'),
                                'img' => HOTSUGAR_DIR . 'assets/img/media_small.png'
                            ),
                            'large' => array(
                                'alt' => esc_html__('Featured area large', 'hotsugar'),
                                'title' => esc_html__('Featured area large', 'hotsugar'),
                                'img' => HOTSUGAR_DIR . 'assets/img/media_large.png'
                            ),
                            'fullwidth' => array(
                                'alt' => esc_html__('Featured area fullwidth', 'hotsugar'),
                                'title' => esc_html__('Featured area fullwidth', 'hotsugar'),
                                'img' => HOTSUGAR_DIR . 'assets/img/media_fullwidth.png'
                            ),
                            'fullscreen' => array(
                                'alt' => esc_html__('Featured area fullscreen', 'hotsugar'),
                                'title' => esc_html__('Featured area fullscreen', 'hotsugar'),
                                'img' => HOTSUGAR_DIR . 'assets/img/media_fullscreen.png'
                            ),
                            'none' => array(
                                'alt' => esc_html__('Featured area none', 'hotsugar'),
                                'title' => esc_html__('Featured area None', 'hotsugar'),
                                'img' => HOTSUGAR_DIR . 'assets/img/slider_empty.png'
                            )
                        ),
                        'default'  => 'small'
                    ),
                    array(
                        'id'       => 'single_scroll',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Single Scrollbar', 'hotsugar'),
                        'default'  => 0,
                    ),
                    array(
                        'id'       => 'sidebar_affix',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Sidebar Affix', 'hotsugar'),
                        'subtitle' => esc_html__( 'If you set this on Sidebar areas will be affixed.', 'hotsugar'),
                        'default'  => 0,
                    ),
                    array(
                        'id'       => 'gif_auto_single',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'GIF auto play on blog single?', 'hotsugar'),
                        'subtitle'     => esc_html__( 'In the Blog Single it can be autplay or Play button', 'hotsugar'),
                        'default'  => 0,
                    ),
                    array(
                        'id'       => 'single_share',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Post share on single?', 'hotsugar'),
                        'subtitle'     => esc_html__( 'Social shares visible or not on Single Post area', 'hotsugar'),
                        'default'  => 1,
                    ),
                    array(
                        'id'       => 'single_pagination',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Next, Prev post on single?', 'hotsugar'),
                        'default'  => 1,
                    ),
                    array(
                        'id'       => 'single_cats',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Post cats on single?', 'hotsugar'),
                        'subtitle'     => esc_html__( 'Post categories', 'hotsugar'),
                        'default'  => 1,
                    ),
                    array(
                        'id'       => 'single_meta',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Post meta on single?', 'hotsugar'),
                        'subtitle'     => esc_html__( 'Post date and author', 'hotsugar'),
                        'default'  => 1,
                    ),
                    array(
                        'id'       => 'single_tags',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Post tags on single?', 'hotsugar'),
                        'subtitle'     => esc_html__( 'Tag on single', 'hotsugar'),
                        'default'  => 1,
                    ),
                    array(
                        'id'       => 'single_author',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Post author on single?', 'hotsugar'),
                        'subtitle'     => esc_html__( 'About author on single', 'hotsugar'),
                        'default'  => 1,
                    ),
                array(
                    'id'=>'blog-single-end',
                    'type' => 'section', 
                    'indent' => false // Indent all options below until the next 'section' option is set.
                ),
        )
    ) );
    
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Color', 'hotsugar'),
        'id'         => 'color',
        'icon'       => 'el el-eye-open',
        'fields'     => array(
            array(
                'id'       => 'primary_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Primary Color?', 'hotsugar'),
                'subtitle' => esc_html__('This is your main Primary Color.','hotsugar'),   
                'default'  => '#ff1155',
            ),
            array(
                'id'=>'body-section-start',
                'type' => 'section',
                'title' => esc_html__('General Color', 'hotsugar'),
                'indent' => true // Indent all options below until the next 'section' option is set.
                ),
            array(
                'id'       => 'body_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Body Color?', 'hotsugar'),
                'default'  => '#666',
            ),
            array(         
                'id'       => 'body_bg',
                'type'     => 'background',
                'title'    => esc_html__('Body Background', 'hotsugar'),
                'subtitle' => esc_html__('This will works whole background area. If you chosen the Boxed Layout then it will work outside of Container area. It will not work if you have chosen Full Layout', 'hotsugar'),
                'default'  => array(
                    'background-color' => '#f2f2f2',
                )
            ),
            array(         
                'id'       => 'ex_sidebar_bg',
                'type'     => 'color',
                'title'    => esc_html__('Extended Sidebar Menu Background', 'hotsugar'),
                'subtitle' => esc_html__('Extended Sidebar Menu Background Color', 'hotsugar'),
                'default'  => '#151515',
                'output'   => array(
                    'background-color' => '.tw-mobile-menu'
                )
            ),
            array(         
                'id'       => 'ex_sidebar_color',
                'type'     => 'color',
                'title'    => esc_html__('Extended Sidebar Menu Text Color', 'hotsugar'),
                'subtitle' => esc_html__('Extended Sidebar Menu Text Color', 'hotsugar'),
                'default'  => '#fff',
                'output'   => array(
                    'color' => '.tw-mobile-menu .widget-item',
                    'background-color' => '.mCSB_scrollTools .mCSB_dragger .mCSB_dragger_bar, .mCSB_scrollTools .mCSB_dragger:active .mCSB_dragger_bar, .mCSB_scrollTools .mCSB_dragger.mCSB_dragger_onDrag .mCSB_dragger_bar'
                )
            ),
            array(         
                'id'       => 'ex_link_color',
                'type'     => 'link_color',
                'title'    => esc_html__('Extended Sidebar Menu Link Color', 'hotsugar'),
                'subtitle' => esc_html__('Extended Sidebar Menu Link Color', 'hotsugar'),
                'active'   => false,
                'default'  => array(
                    'regular' => '#fff',
                    'hover' => '#ff1155'
                ),
                'output'   => array(
                    'color' => '.tw-mobile-menu nav ul li a, .tw-mobile-menu nav ul li a:after, .tw-mobile-menu .page_item > ul.children li > a, .tw-mobile-menu .sub-menu li > a'
                )
            ),
            array(         
                'id'       => 'ex_heading_color',
                'type'     => 'color',
                'title'    => esc_html__('Extended Sidebar Menu Heading Color', 'hotsugar'),
                'subtitle' => esc_html__('Extended Sidebar Menu Heading Color', 'hotsugar'),
                'default'  => '#fff',
                'output'   => array(
                    'color' => '.tw-mobile-menu .tw-logo a, .tw-mobile-menu h3.widget-title'
                )
            ),
            array(
                'id'       => 'container_bg',
                'type'     => 'color',
                'title'    => esc_html__( 'Content area BG Color?', 'hotsugar'),
                'default'  => '#fff',
            ),
            array(
                'id'       => 'heading_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Heading Title Color (H1-H6)?', 'hotsugar'),
                'default'  => '#151515',
            ),
            array(
                'id'       => 'post_metacolor',
                'type'     => 'color',
                'title'    => esc_html__( 'Blog Meta Color?', 'hotsugar'),
                'subtitle' => esc_html__( 'Post Share & Post Comment and Date?', 'hotsugar'),
                'default'  => '#999',
            ),
            array(
                'id'       => 'link_color',
                'type'     => 'link_color',
                'title'    => esc_html__( 'Link Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => array(
                    'regular' => '#111',
                    'hover'   => '#999',
                    'active'  => false,
                )
            ),
            array(
                'id'       => 'light_social_bg',
                'type'     => 'color',
                'title'    => esc_html__( 'Light Social BG Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#ccc',
                'output'   => array(
                    'background-color' => '.blog-single-nav .entry-share i, .tw-social-icon i'
                )
            ),
            array(
                'id'       => 'light_social_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Light Social Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#fff',
                'output'   => array(
                    'color' => '.blog-single-nav .entry-share i, .tw-social-icon i'
                )
            ),
            array(
                'id'       => 'dark_social_bg',
                'type'     => 'color',
                'title'    => esc_html__( 'Dark Social BG Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#333',
                'output'   => array(
                    'background-color' => '.blog-single-nav .entry-share.dark i, .tw-social-icon.social-dark i'
                )
            ),
            array(
                'id'       => 'dark_social_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Dark Social Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#999',
                'output'   => array(
                    'color' => '.blog-single-nav .entry-share.dark i, .tw-social-icon.social-dark i'
                )
            ),
            
            
            array(
                'id'=>'body-section-end',
                'type' => 'section', 
                'indent' => false // Indent all options below until the next 'section' option is set.
            ),
            
            array(
                'id'=>'header-section-start',
                'type' => 'section',
                'title' => esc_html__('Header Area Colors', 'hotsugar'),                           
                'indent' => true // Indent all options below until the next 'section' option is set.
                ),
            array(
                'id'       => 'header_bgcolor',
                'type'     => 'color',
                'title'    => esc_html__( 'Header BG Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#fff',
            ),
            array(
                'id'            => 'header_opacity',
                'type'          => 'slider',
                'title'         => esc_html__( 'Fullscreen Slider Header Opacity', 'hotsugar' ),
                'subtitle'      => esc_html__( 'This option will work only the Slider is Fullscreen and Slider Layout 2 has chosen.', 'hotsugar' ),
                'desc'          => '',
                'default'       => '0',
                'min'           => 0,
                'step'          => 10,
                'max'           => 100,
                'display_value' => 'text'
            ),
            array(
                'id'       => 'menu_color',
                'type'     => 'color',
                'title'    => esc_html__('Header area text color?', 'hotsugar'),
                'subtitle' => esc_html__('Note: menu,logo and search icon?', 'hotsugar'),
                'default'  => '#151515',
            ),
            array(
                'id'       => 'menu_hover',
                'type'     => 'color',
                'title'    => esc_html__('Menu hover color?', 'hotsugar'),
                'subtitle' => esc_html__('If you want to disable it then set the same color for Header area text color.', 'hotsugar'),
                'default'  => '#ff1155',
            ),
            array(
                'id'       => 'submenu_bg',
                'type'     => 'color',
                'title'    => esc_html__('SubMenu BG color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#151515',
            ),
            array(
                'id'       => 'submenu_hover_bg',
                'type'     => 'color',
                'title'    => esc_html__('SubMenu Hover BG color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#ff1155',
            ),
            array(
                'id'       => 'submenu_color',
                'type'     => 'color',
                'title'    => esc_html__('SubMenu Text color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#fff',
            ),
            array(
                'id'       => 'submenu_hover_color',
                'type'     => 'color',
                'title'    => esc_html__('SubMenu Hover Text color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#fff',
            ),
           
            array(
                'id'=>'header-section-end',
                'type' => 'section', 
                'indent' => false // Indent all options below until the next 'section' option is set.
            ),
            
            array(
                'id'=>'footer-section-start',
                'type' => 'section',
                'title' => esc_html__('Footer Area Colors', 'hotsugar'),                           
                'indent' => true // Indent all options below until the next 'section' option is set.
                ),
            array(
                'id'       => 'footer_bgcolor',
                'type'     => 'color',
                'title'    => esc_html__( 'Footer BG Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#151515',
            ),
            array(
                'id'       => 'footer_text_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Footer Text Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#999',
            ),
            array(
                'id'       => 'footer_widget_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Footer Widget Text Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#ccc',
            ),
            array(
                'id'       => 'footer_heading_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Footer Heading Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => '#fff',
            ),
            array(
                'id'       => 'footer_link_color',
                'type'     => 'link_color',
                'title'    => esc_html__( 'Link Color?', 'hotsugar'),
                'subtitle' => '',
                'default'  => array(
                    'regular' => '#ccc',
                    'hover'   => '#fff',
                    'active'  => false,
                )
            ),
            array(
                'id'=>'footer-section-end',
                'type' => 'section', 
                'indent' => false // Indent all options below until the next 'section' option is set.
            ),
            
            array(
                'id'=>'scrollbar-section-start',
                'type' => 'section',
                'title' => esc_html__('Single Scrollbar Colors', 'hotsugar'),                           
                'indent' => true // Indent all options below until the next 'section' option is set.
                ),
            
            array(         
                'id'       => 'single_scrollbar_bg',
                'type'     => 'color',
                'title'    => esc_html__('Single Scrollbar Background', 'hotsugar'),
                'subtitle' => esc_html__('Choose Single Scrollbar Background Color', 'hotsugar'),
                'default'  => '#151515',
                'output'   => array(
                    'background-color' => '.blog-single-nav'
                )
            ),
            array(         
                'id'       => 'single_scrollbar_color',
                'type'     => 'color',
                'title'    => esc_html__('Single Scrollbar Text Color', 'hotsugar'),
                'subtitle' => esc_html__('Choose Single Scrollbar Text Color', 'hotsugar'),
                'default'  => '#fff',
                'output'   => array(
                    'color' => '.blog-single-nav h2, .blog-single-nav .site-name, .blog-single-nav .entry-share .total-shares'
                )
            ),
           array(
            'id'       => 'single_scrollbar_social',
            'type'     => 'select',
            'title'    => esc_html__( 'Single social color', 'hotsugar' ),
            'subtitle' => esc_html__( 'You can change it', 'hotsugar' ),
            'options'  => array(
                'light' => 'Light',
                'dark' => 'Dark'
            ),
            'default'  => 'dark'
        ),
            array(
                'id'=>'scrollbar-section-end',
                'type' => 'section', 
                'indent' => false // Indent all options below until the next 'section' option is set.
            ),
        )
    ) );

    // -> START Typography
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Typography', 'hotsugar'),
        'id'     => 'typography',
        'icon'   => 'el el-fontsize',
        'fields' => array(
            array(
                'id'       => 'body_font',
                'type'     => 'typography',
                'title'    => esc_html__( 'Body Font', 'hotsugar'),
                'subtitle' => esc_html__( 'Site whole Text on Body area.', 'hotsugar'),
                'google'   => true,
                'font-style'  => true,
                'font-weight'  => true,
                'text-align'  => false,
                'color'  => false,
                'all_styles'  => true,
                'font-backup'  => true,
                'line-height'  => false,
                'default'  => array(
                    'font-size'   => '14px',
                    'font-family' => 'Poppins',
                    'font-weight' => '400',
                    'font-backup'  => 'Arial, Helvetica, sans-serif',
                ),
            ),
            array(
                'id'          => 'menu_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'Main Menu Font', 'hotsugar'),
                'google'   => true,
                'font-style'  => true,
                'font-weight'  => true,
                'text-align'  => false,
                'text-transform'  => true,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-family' => 'Poppins',
                    'font-size'   => '12px',
                    'font-style'  => '',
                    'text-transform'  => 'uppercase',
                    'font-weight' => '600'
                )
            ),
            array(
                'id'          => 'submenu_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'SubMenu font size', 'hotsugar'),
                'google'   => true,
                'font-family'  => true,
                'font-style'  => false,
                'font-weight'  => true,
                'text-transform'  => true,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '12',
                    'font-weight'  => '600',
                    'text-transform'  => 'uppercase',
                )
            ),
            array(
                'id'          => 'meta_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'Post Meta Font', 'hotsugar'),
                'subtitle'    => esc_html__( 'Date time, comment count and share count.', 'hotsugar'),
                'google'   => true,
                'font-style'  => true,
                'font-weight'  => true,
                'text-align'  => false,
                'color'  => false,
                'text-transform'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-family' => 'Poppins',
                    'font-weight' => '400',
                    'font-size'  => '10px',
                ),
            ),
            array(
                'id'          => 'heading_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'Heading Title Font', 'hotsugar'),
                'subtitle'    => esc_html__( 'H1-H6 and any Post Titles.', 'hotsugar'),
                'google'   => true,
                'font-style'  => true,
                'font-weight'  => true,
                'text-align'  => false,
                'text-transform'  => true,
                'color'  => false,
                'font-size'  => false,
                'line-height'  => false,
                'all_styles'  => true,
                'default'  => array(
                    'font-family' => 'Poppins',
                    'font-style'  => '',
                    'text-transform'  => 'none',
                    'font-weight' => '600'
                ),
            ),
            array(
                'title' => esc_html__('Heading Title Tags Size', 'hotsugar'),
                'id' => 'tab_typography_sub_tag_start',
                'type' => 'section',
                'indent' => true,
            ),
            
            array(
                'id'          => 'h1_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H1', 'hotsugar'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '36',
                )
            ),
            array(
                'id'          => 'h2_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H2', 'hotsugar'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '30',
                )
            ),
            array(
                'id'          => 'h3_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H3', 'hotsugar'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '24',
                )
            ),
            array(
                'id'          => 'h4_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H4', 'hotsugar'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '20',
                )
            ),
            array(
                'id'          => 'h5_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H5', 'hotsugar'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '18',
                )
            ),
            array(
                'id'          => 'h6_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H6', 'hotsugar'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '16',
                )
            ),
            array(
                'id' => 'tab_typography_sub_tag_end',
                'type' => 'section',
                'indent' => false,
            ),
        )
    ) );
    
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Footer', 'hotsugar'),
        'id'         => 'footer',
        'icon'       => 'el el-photo',
        'fields'     => array(
            array(
                'id'       => 'footer_layout',
                'type'     => 'select',
                'title'    => esc_html__( 'Footer Layout', 'hotsugar'),
                'subtitle'    => esc_html__( 'Total Grid Column is 12 and back numbers are defined the Column Grid', 'hotsugar'),
                'desc'    => esc_html__( '(6-3-3) => (col-md-6, col-md-3, col-md-3)', 'hotsugar'),
                'options'   => array('' => 'None',
                                     '12' => '1 Column (12)',
                                     '6-6' => '2 Columns (6-6)',
                                     '4-4-4' => '3 Columns (4-4-4)',
                                     '6-3-3' => '3 Columns (6-3-3)',
                                     '3-3-3-3' => '4 Columns (3-3-3-3)'),
                'default'  => '',
            ),
            array(
                'id'       => 'footer_text1',
                'type'     => 'textarea',
                'title'    => esc_html__('Footer Left Text', 'hotsugar'),
                'subtitle' => esc_html__('You can use HTML tags on this area', 'hotsugar'),
                'default'  => esc_html__('&copy; Copyright 2017. All Rights Reserved.', 'hotsugar'),
            ),
            array(
                'id'       => 'footer_text2',
                'type'     => 'textarea',
                'title'    => esc_html__( 'Footer Right Text', 'hotsugar'),
                'subtitle' => esc_html__( 'You can use HTML tags on this area', 'hotsugar'),
                'default'  => wp_kses_post(sprintf(__( 'Designed & Developed by <a href="%s">Themewaves</a>', 'hotsugar'),'https://themeforest.net/user/themewaves')),
            )
        )
    ) );
    
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Translation', 'hotsugar'),
        'id'         => 'translation',
        'icon'       => 'el el-globe',
        'fields'     => array(
            array(
                'id'       => 'readmore',
                'type'     => 'text',
                'title'    => esc_html__( 'Read more text on Slider', 'hotsugar'),
                'subtitle' => '',
                'default'  => esc_html__( 'Read more', 'hotsugar'),
            ),
            array(
                'id'       => 'text_older',
                'type'     => 'text',
                'title'    => esc_html__( 'Older posts text on Pagination', 'hotsugar'),
                'subtitle' => '',
                'default'  => esc_html__( 'Older Posts', 'hotsugar'),
            ),
            array(
                'id'       => 'text_newer',
                'type'     => 'text',
                'title'    => esc_html__( 'Newer posts text on Pagination', 'hotsugar'),
                'subtitle' => '',
                'default'  => esc_html__( 'Newer Posts', 'hotsugar'),
            ),
            array(
                'id'       => 'text_prev',
                'type'     => 'text',
                'title'    => esc_html__( 'Prev posts text on Numbered Pagination', 'hotsugar'),
                'subtitle' => '',
                'default'  => esc_html__( 'Prev', 'hotsugar'),
            ),
            array(
                'id'       => 'text_next',
                'type'     => 'text',
                'title'    => esc_html__( 'Next posts text on Numbered Pagination', 'hotsugar'),
                'subtitle' => '',
                'default'  => esc_html__( 'Next', 'hotsugar'),
            ),
            array(
                'id'       => 'text_loadmore',
                'type'     => 'text',
                'title'    => esc_html__( 'Load More on Infinite Pagination', 'hotsugar'),
                'subtitle' => '',
                'default'  => esc_html__( 'Load More', 'hotsugar'),
            ),
            array(
                'id'       => 'text_search',
                'type'     => 'text',
                'title'    => esc_html__( 'Search placeholder', 'hotsugar'),
                'subtitle' => '',
                'default'  => esc_html__( 'Type Something & Press Enter ...', 'hotsugar'),
            ),
        )
    ) );
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Custom CSS', 'hotsugar'),
        'id'         => 'custom_css_tab',
        'icon'       => 'el el-css',
        'fields'     => array(
            array(
                'id'       => 'custom_css',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Custom CSS', 'hotsugar'),
                'subtitle' => esc_html__('Paste your CSS code here.', 'hotsugar'),
                'mode'     => 'css',
                'theme'    => 'chrome',
            )
        )
    ) );
    Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Ads management', 'hotsugar' ),
        'id'    => 'adsense',
        'desc'  => '',
        'icon'  => 'el el-screenshot',
        'fields' => array(
            array(
                'id'       => 'ads-single',
                'type'     => 'editor',
                'title'    => esc_html__('Single Content Above', 'hotsugar'), 
                'subtitle' => esc_html__('It will be displayed above the Single Content, You can insert anything Ad or custom image or text anything.', 'hotsugar'),
                'desc'    => '', 
                'default'  => '',
                'args'   => array(
                    'teeny'            => true,
                    'textarea_rows'    => 5
                )
            ),
            array(
                'id'       => 'ads-blog',
                'type'     => 'editor',
                'title'    => esc_html__('Blog Page Above', 'hotsugar'), 
                'subtitle' => esc_html__('It will be displayed above the Blog Page, You can insert anything Ad or custom image or text anything.', 'hotsugar'),
                'desc'    => '', 
                'default'  => '',
                'args'   => array(
                    'teeny'            => true,
                    'textarea_rows'    => 5
                )
            ),
        )
    ));
