<?php

$theme_obj = wp_get_theme();
$theme_name = $theme_obj->get('Name');
$theme_version = $theme_obj->get('Version');

define('HOTSUGAR_THEMENAME', $theme_name);
define('HOTSUGAR_THEMEVERSION', $theme_version);
define('HOTSUGAR_META', 'themewaves_' . strtolower(str_replace(' ', '_', HOTSUGAR_THEMENAME)) . '_options');
define('HOTSUGAR_PATH', trailingslashit(get_template_directory()));
define('HOTSUGAR_DIR', trailingslashit(get_template_directory_uri()));
define('HOTSUGAR_STYLESHEET_DIR', trailingslashit(get_stylesheet_directory_uri()));

if (is_admin()) {
    require( HOTSUGAR_PATH . 'framework/tgm-plugins.php');
    add_action('admin_print_scripts', 'hotsugar_admin_scripts');
    add_action('admin_print_styles', 'hotsugar_admin_styles');

    function hotsugar_admin_scripts() {
        $pid = isset($post->ID) ? $post->ID : 0;
        wp_localize_script('jquery', 'hotsugar_script_data', array(
            'home_uri' => esc_url(home_url('/')),
            'post_id' => esc_attr($pid),
            'nonce' => esc_attr(wp_create_nonce('themewaves-ajax')),
            'image_ids' => esc_attr(hotsugar_metabox('gallery_image_ids')),
            'label_create' => esc_html__("Create Featured Gallery", 'hotsugar'),
            'label_edit' => esc_html__("Edit Featured Gallery", 'hotsugar'),
            'label_save' => esc_html__("Save Featured Gallery", 'hotsugar'),
            'label_saving' => esc_html__("Saving...", 'hotsugar')
        ));
        wp_register_script('hotsugar-admin-js', HOTSUGAR_DIR . 'framework/js/waves-admin.js');
        wp_enqueue_script('hotsugar-admin-js');
    }

    function hotsugar_admin_styles() {
        wp_register_style('hotsugar-admin-css', HOTSUGAR_DIR . 'framework/css/waves-admin.css', false, '1.00', 'screen');
        wp_enqueue_style('hotsugar-admin-css');
    }

}

require_once (HOTSUGAR_PATH . "framework/waves_options/waves-options.php");
require_once (HOTSUGAR_PATH . "framework/theme_functions.php");
require_once (HOTSUGAR_PATH . "framework/blog_functions.php");
require_once (HOTSUGAR_PATH . "framework/waves_widget/widget_socials.php");
require_once (HOTSUGAR_PATH . "framework/waves_widget/widget_text.php");
require_once (HOTSUGAR_PATH . "framework/waves_widget/widget_post.php");
require_once (HOTSUGAR_PATH . "framework/waves_widget/widget_instagram.php");
require_once (HOTSUGAR_PATH . "framework/waves_widget/widget_social_tabs.php");
require_once (HOTSUGAR_PATH . "framework/theme_css.php");



/* ================================================================================== */
/*      Theme Supports
  /* ================================================================================== */

add_action('after_setup_theme', 'hotsugar_setup');
if (!function_exists('hotsugar_setup')) {

    function hotsugar_setup() {
        add_editor_style();
        add_theme_support('post-thumbnails');
        add_theme_support('post-formats', array('gallery', 'video', 'audio'));
        add_theme_support('title-tag');
        add_theme_support('automatic-feed-links');
        load_theme_textdomain('hotsugar', HOTSUGAR_PATH . 'languages/');
        register_nav_menus(array('main' => esc_html__('Main Menu', 'hotsugar')));
        register_nav_menus(array('top' => esc_html__('Top Menu', 'hotsugar')));

        add_image_size('hotsugar_blog_large', 940, 500, true);
        add_image_size('hotsugar_blog_thumb', 620, 360, true);
        add_image_size('hotsugar_grid_thumb', 460, 300, true);
        add_image_size('hotsugar_carousel_1', 300, 180, true);
        add_image_size('hotsugar_carousel_2', 300, 400, true);
        add_image_size('hotsugar_carousel_3', 420, 840, true);
        add_image_size('hotsugar_masonry_thumb', 460);
    }

}
if (!isset($content_width)) {
    $content_width = 960;
}



/* ================================================================================== */
/*      Enqueue Scripts
  /* ================================================================================== */

add_action('wp_enqueue_scripts', 'hotsugar_scripts');

function hotsugar_scripts() {
    wp_enqueue_style('bootstrap', HOTSUGAR_DIR . 'assets/css/bootstrap.min.css');
    wp_enqueue_style('ionicons', HOTSUGAR_DIR . 'assets/css/ionicons.min.css');
    wp_enqueue_style('hotsugar-style', HOTSUGAR_DIR . 'style.css');
    wp_enqueue_style('hotsugar-responsive', HOTSUGAR_DIR . 'assets/css/responsive.css');
    wp_add_inline_style('hotsugar-responsive', hotsugar_option_styles());

    wp_enqueue_script('hotsugar-functions', HOTSUGAR_DIR . 'assets/js/functions.js', false, false, false);
    wp_enqueue_script('hotsugar-scripts', HOTSUGAR_DIR . 'assets/js/scripts.js', array('jquery'), false, true);
    if (is_single() && comments_open()) {
        wp_enqueue_script('comment-reply');
    }
    wp_enqueue_script('html5', HOTSUGAR_DIR . 'assets/js/html5.js', array(), '3.6.0');
    wp_script_add_data('html5', 'conditional', 'lt IE 9');
    wp_enqueue_script('owl-carousel', HOTSUGAR_DIR . 'assets/js/owl.carousel.min.js');
    wp_register_script('hotsugar-isotope', HOTSUGAR_DIR . 'assets/js/jquery.waves-isotope.min.js');
    wp_register_script('jarallax', HOTSUGAR_DIR . 'assets/js/jarallax.js');
    if (hotsugar_option('sidebar_affix')) {
        wp_enqueue_script('theiastickysidebar', HOTSUGAR_DIR . 'assets/js/theiaStickySidebar.js', false, false, true);
    }
    wp_enqueue_script('hotsugar-script', HOTSUGAR_DIR . 'assets/js/waves-script.js');
    wp_localize_script('jquery', 'hotsugar_script_data', array(
        'gif_auto' => is_single() ? hotsugar_option('gif_auto_single', '0') : hotsugar_option('gif_auto_blog', '1'),
        'slider_auto' => hotsugar_option('slider_auto', '0') ? true : false,
        'slider_delay' => hotsugar_option('slider_delay', '3000'),
    ));
}

/* ================================================================================== */
/*      Register Widget Sidebar
  /* ================================================================================== */

if (!function_exists('hotsugar_widgets_init')) {

    function hotsugar_widgets_init() {
        register_sidebar(array(
            'name' => esc_html__('Default sidebar', 'hotsugar'),
            'id' => 'default-sidebar',
            'before_widget' => '<aside class="widget %2$s" id="%1$s"><div class="widget-item">',
            'after_widget' => '</div></aside>',
            'before_title' => '</div><h3 class="widget-title"><span>',
            'after_title' => '</span></h3><div class="widget-item">',
        ));
        register_sidebar(array(
            'name' => esc_html__('Navigation sidebar', 'hotsugar'),
            'id' => 'navigation-sidebar',
            'before_widget' => '<aside class="widget %2$s" id="%1$s"><div class="widget-item">',
            'after_widget' => '</div></aside>',
            'before_title' => '</div><h3 class="widget-title"><span>',
            'after_title' => '</span></h3><div class="widget-item">',
        ));
        /* footer sidebar */
        $footer = hotsugar_option('footer');
        $footer = 1;
        if ($footer) {
            $grid = '1-2-3';
            foreach (explode('-', $grid) as $i) {
                register_sidebar(array(
                    'name' => esc_html__("Footer sidebar", 'hotsugar') . ' ' . $i,
                    'id' => "footer-sidebar-$i",
                    'description' => esc_html__('The footer sidebar widget area', 'hotsugar'),
                    'before_widget' => '<div class="widget %2$s" id="%1$s">',
                    'after_widget' => '</div>',
                    'before_title' => '<h3 class="widget-title"><span>',
                    'after_title' => '</span></h3>',
                ));
            }
        }
    }

}
add_action('widgets_init', 'hotsugar_widgets_init');



/* ================================================================================== */
/*      ThemeWaves Search Form Customize
  /* ================================================================================== */

function hotsugar_searchmenu() {
    $form = '<form method="get" class="searchform on-menu" action="' . esc_url(home_url('/')) . '" >';
    $form .= '<div class="input"><input type="text" value="' . get_search_query() . '" name="s" placeholder="' . esc_html__('Search', 'hotsugar') . '" /><i class="ion-search"></i></div>';
    $form .= '</form>';
    return $form;
}

function hotsugar_searchform() {

    $form = '<form method="get" class="searchform" action="' . esc_url(home_url('/')) . '" >
    <div class="input">
    <input type="text" value="' . get_search_query() . '" name="s" placeholder="' . esc_html__('Keyword ...', 'hotsugar') . '" />
        <button type="submit" class="button-search"><i class="ion-search"></i></button>
    </div>
    </form>';

    return $form;
}

add_filter('get_search_form', 'hotsugar_searchform');

/* Exclude Category */

function hotsugar_exclude_widget_cats($args) {
    $categories = get_categories();
    $exclude = array();
    foreach ($categories as $category) {
        $options = get_option("taxonomy_" . $category->cat_ID);
        if (isset($options['featured']) && $options['featured']) {
            $exclude[] = $category->cat_ID;
        }
    }
    $args["exclude"] = $exclude;
    return $args;
}

add_filter("widget_categories_args", "hotsugar_exclude_widget_cats");

/* WordPress Edit Gallery */
add_filter('use_default_gallery_style', '__return_false');
add_filter('wp_get_attachment_link', 'hotsugar_pretty_gallery', 10, 5);

function hotsugar_pretty_gallery($content, $id, $size = 'large', $permalink) {
    if (!$permalink)
        $content = preg_replace("/<a/", "<a rel=\"prettyPhoto[gallery]\"", $content, 1);
    $content = preg_replace("/<\/a/", "<div class=\"image-overlay\"></div></a", $content, 1);
    return $content;
}

function hotsugar_body_class($classes) {
    global $hotsugar_options;

    if (is_single()) {
        $hotsugar_options['single_media'] = hotsugar_metabox('single_media');
        if (empty($hotsugar_options['single_media'])) {
            $hotsugar_options['single_media'] = hotsugar_option('single_media', 'small');
        }
        if ($hotsugar_options['single_media'] == 'fullscreen') {
            $classes[] = 'transparent-header';
        }
    } elseif (is_page() && hotsugar_metabox('slider') == 'slider4') {
        $classes[] = 'transparent-header';
    }
    if (hotsugar_option('theme_layout') == 'boxed') {
        $classes[] = 'theme-boxed';
    }

    return $classes;
}

add_filter('body_class', 'hotsugar_body_class');
